package service

import (
	"strconv"
	"strings"
	"sws_xcx/models"
	"sws_xcx/utils"

	"github.com/jinzhu/gorm"
)

type CheckRecordService struct {
	rdb *gorm.DB
	wdb *gorm.DB
}

func NewCheckRecordService() *CheckRecordService {
	return &CheckRecordService{
		rdb: ReadDB(),
		wdb: WriteDB(),
	}
}

func (s *CheckRecordService) GetCheckRecordByAcc(deviceId uint64, acc int) (record models.CheckRecord, err error) {
	record = models.CheckRecord{}
	err = s.rdb.Model(&record).Where("device_id = ? and acc = ?", deviceId, acc).First(&record).Error
	if err != nil && err == gorm.ErrRecordNotFound {
		err = nil
	}

	return
}

func (s *CheckRecordService) GetCheckRecordList(pageNum, pageSize int, userid uint64) (vos []models.AppCheckRecordVO, total int, err error) {
	offset := (pageNum - 1) * pageSize
	records := make([]*models.CheckRecord, pageSize)
	err = s.rdb.Model(&models.CheckRecord{}).Where("user_id= ? and delete_flag = ?", 0).Count(&total).Order("id desc").Offset(offset).Limit(pageSize).Find(&records).Error
	if len(records) > 0 {
		is := NewCheckItemService()
		cnItems, err1 := is.GetCheckItems("cn", "1")
		if err1 != nil {
			utils.ErrorLog("GetCheckItems err：%v ", err1)
		}
		mcn := make(map[int]models.CheckItem, len(cnItems))
		for _, item := range cnItems {
			mcn[item.Id] = *item
		}

		vos = make([]models.AppCheckRecordVO, len(records))
		for i, r := range records {
			vo := models.AppCheckRecordVO{}
			vo.CheckRecordId = r.Id
			vo.UserId = r.UserId
			if r.UserId > 0 {
				vo.Bind = 1
			}
			vo.CheckDate = models.Time(r.Ctime)
			vo.View = r.View
			vo.AlertCount = 0
			//vo.AlertGrade = 0

			if r.AlertItemIds != "" {
				ids := strings.Split(r.AlertItemIds, ",")
				names := make([]string, len(ids))
				for j, id := range ids {

					ii, _ := strconv.Atoi(id)
					if item, ok := mcn[ii]; ok {
						names[j] = item.NameCn
					}

				}
				vo.AlertItems = names
				vo.AlertCount = len(ids)
			}
			vo.NormalCount = len(cnItems) - vo.AlertCount

			vos[i] = vo
		}

	}

	return
}

func (s *CheckRecordService) CreateCheckRecord(checkRecord *models.CheckRecord) error {
	return s.wdb.Model(checkRecord).Create(checkRecord).Error
}

func (s *CheckRecordService) CreateCheckRecordItem(checkRecordItem *models.CheckRecordItem) error {
	return s.wdb.Model(checkRecordItem).Create(checkRecordItem).Error
}

func (s *CheckRecordService) UpdateCheckRecordAlertItems(id int64, alertItemIds string) error {
	return s.wdb.Model(&models.CheckRecord{}).Where("id = ?", id).Update("alert_item_ids", alertItemIds).Error
}

func (s *CheckRecordService) GetCheckRecordItems(recordId int64) (recordItems []*models.CheckRecordItem, err error) {
	err = s.rdb.Model(&models.CheckRecordItem{}).Where("check_id = ?", recordId).Find(&recordItems).Error
	return
}

func (s *CheckRecordService) GetCheckRecordById(id int64) (record models.CheckRecord, err error) {

	err = s.rdb.Model(&record).Where("id = ?", id).First(&record).Error
	return
}
